# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/participant_transaction.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/participant_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_merkle__pb2
from . import quorum_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_quorum__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBcom/digitalasset/canton/protocol/v30/participant_transaction.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/common.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/merkle.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/quorum.proto\x1a\x1egoogle/protobuf/duration.proto\"r\n\x13\x44\x65\x64uplicationPeriod\x12\x37\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x08\x64uration\x12\x18\n\x06offset\x18\x02 \x01(\x03H\x00R\x06offsetB\x08\n\x06period\"\xc0\x01\n\x13ParticipantMetadata\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x1f\n\x0bledger_time\x18\x02 \x01(\x03R\nledgerTime\x12)\n\x10preparation_time\x18\x03 \x01(\x03R\x0fpreparationTime\x12\x1f\n\x0bworkflow_id\x18\x04 \x01(\tR\nworkflowId\"\x89\x02\n\x0fRootHashMessage\x12\x1b\n\troot_hash\x18\x01 \x01(\x0cR\x08rootHash\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\x12K\n\tview_type\x18\x03 \x01(\x0e\x32..com.digitalasset.canton.protocol.v30.ViewTypeR\x08viewType\x12\x38\n\x18submission_topology_time\x18\x04 \x01(\x03R\x16submissionTopologyTime\x12\x18\n\x07payload\x18\x05 \x01(\x0cR\x07payload\"\x9f\x02\n\x08ViewNode\x12]\n\x10view_common_data\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x0eviewCommonData\x12g\n\x15view_participant_data\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x13viewParticipantData\x12K\n\x08subviews\x18\x03 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.MerkleSeqR\x08subviews\"\xb4\x01\n\x0eViewCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x1c\n\tinformees\x18\x02 \x03(\tR\tinformees\x12\x46\n\x07quorums\x18\x03 \x03(\x0b\x32,.com.digitalasset.canton.protocol.v30.QuorumR\x07quorums\"8\n\x08Informee\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weight\"\x1c\n\x16ViewParticipantMessage:\x02\x18\x01\"\xf0\x01\n\x0fInformeeMessage\x12\x64\n\x12\x66ull_informee_tree\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.FullInformeeTreeR\x10\x66ullInformeeTree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xd5\x01\n\x18LightTransactionViewTree\x12L\n\x04tree\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.GenTransactionTreeR\x04tree\x12k\n\x17subview_hashes_and_keys\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ViewHashAndKeyR\x14subviewHashesAndKeys\"r\n\x0eViewHashAndKey\x12\x1b\n\tview_hash\x18\x01 \x01(\x0cR\x08viewHash\x12\x43\n\x1eview_encryption_key_randomness\x18\x02 \x01(\x0cR\x1bviewEncryptionKeyRandomness\"`\n\x10\x46ullInformeeTree\x12L\n\x04tree\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.GenTransactionTreeR\x04tree\"x\n\x0f\x43reatedContract\x12\x1a\n\x08\x63ontract\x18\x01 \x01(\x0cR\x08\x63ontract\x12(\n\x10\x63onsumed_in_core\x18\x02 \x01(\x08R\x0e\x63onsumedInCore\x12\x1f\n\x0brolled_back\x18\x03 \x01(\x08R\nrolledBack\"G\n\rInputContract\x12\x1a\n\x08\x63ontract\x18\x01 \x01(\x0cR\x08\x63ontract\x12\x1a\n\x08\x63onsumed\x18\x02 \x01(\x08R\x08\x63onsumed\"\xc9\x01\n\x0e\x43ommonMetadata\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12%\n\x0emediator_group\x18\x05 \x01(\x05R\rmediatorGroupJ\x04\x08\x02\x10\x03\"\x85\x04\n\x11SubmitterMetadata\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x15\n\x06\x61\x63t_as\x18\x02 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\x12\x1d\n\ncommand_id\x18\x04 \x01(\tR\tcommandId\x12<\n\x1asubmitting_participant_uid\x18\x05 \x01(\tR\x18submittingParticipantUid\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12\\\n\x0c\x64\x65\x64up_period\x18\x07 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.DeduplicationPeriodR\x0b\x64\x65\x64upPeriod\x12.\n\x13max_sequencing_time\x18\x08 \x01(\x03R\x11maxSequencingTime\x12r\n\x16\x65xternal_authorization\x18\t \x01(\x0b\x32;.com.digitalasset.canton.protocol.v30.ExternalAuthorizationR\x15\x65xternalAuthorization\"\x9c\x04\n\x14\x45ncryptedViewMessage\x12\x1b\n\tview_tree\x18\x01 \x01(\x0cR\x08viewTree\x12\x63\n\x11\x65ncryption_scheme\x18\x02 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x10\x65ncryptionScheme\x12w\n submitting_participant_signature\x18\x03 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\x12\x1b\n\tview_hash\x18\x04 \x01(\x0cR\x08viewHash\x12\x65\n\x12session_key_lookup\x18\x05 \x03(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.AsymmetricEncryptedR\x10sessionKeyLookup\x12\x38\n\x18physical_synchronizer_id\x18\x06 \x01(\tR\x16physicalSynchronizerId\x12K\n\tview_type\x18\x07 \x01(\x0e\x32..com.digitalasset.canton.protocol.v30.ViewTypeR\x08viewType\"\xe0\t\n\x11\x41\x63tionDescription\x12i\n\x06\x63reate\x18\x01 \x01(\x0b\x32O.com.digitalasset.canton.protocol.v30.ActionDescription.CreateActionDescriptionH\x00R\x06\x63reate\x12o\n\x08\x65xercise\x18\x02 \x01(\x0b\x32Q.com.digitalasset.canton.protocol.v30.ActionDescription.ExerciseActionDescriptionH\x00R\x08\x65xercise\x12\x66\n\x05\x66\x65tch\x18\x03 \x01(\x0b\x32N.com.digitalasset.canton.protocol.v30.ActionDescription.FetchActionDescriptionH\x00R\x05\x66\x65tch\x12z\n\rlookup_by_key\x18\x04 \x01(\x0b\x32T.com.digitalasset.canton.protocol.v30.ActionDescription.LookupByKeyActionDescriptionH\x00R\x0blookupByKey\x1aW\n\x17\x43reateActionDescription\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\x1a\xef\x02\n\x19\x45xerciseActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x63hoice\x18\x02 \x01(\tR\x06\x63hoice\x12!\n\x0c\x63hosen_value\x18\x03 \x01(\x0cR\x0b\x63hosenValue\x12\x16\n\x06\x61\x63tors\x18\x04 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x05 \x01(\x08R\x05\x62yKey\x12\x1b\n\tnode_seed\x18\x06 \x01(\x0cR\x08nodeSeed\x12\x16\n\x06\x66\x61iled\x18\x08 \x01(\x08R\x06\x66\x61iled\x12&\n\x0cinterface_id\x18\t \x01(\tH\x00R\x0binterfaceId\x88\x01\x01\x12\x1f\n\x0btemplate_id\x18\n \x01(\tR\ntemplateId\x12-\n\x12package_preference\x18\x0b \x03(\tR\x11packagePreferenceB\x0f\n\r_interface_id\x1a\xcd\x01\n\x16\x46\x65tchActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x61\x63tors\x18\x02 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x03 \x01(\x08R\x05\x62yKey\x12\x1f\n\x0btemplate_id\x18\x04 \x01(\tR\ntemplateId\x12&\n\x0cinterface_id\x18\x05 \x01(\tH\x00R\x0binterfaceId\x88\x01\x01\x42\x0f\n\r_interface_id\x1a\x61\n\x1cLookupByKeyActionDescription\x12\x41\n\x03key\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.GlobalKeyR\x03keyB\r\n\x0b\x64\x65scription\"\xfd\x07\n\x13ViewParticipantData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12T\n\x0b\x63ore_inputs\x18\x02 \x03(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.InputContractR\ncoreInputs\x12X\n\x0c\x63reated_core\x18\x03 \x03(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CreatedContractR\x0b\x63reatedCore\x12K\n#created_in_subview_archived_in_core\x18\x04 \x03(\tR\x1e\x63reatedInSubviewArchivedInCore\x12j\n\rresolved_keys\x18\x05 \x03(\x0b\x32\x45.com.digitalasset.canton.protocol.v30.ViewParticipantData.ResolvedKeyR\x0cresolvedKeys\x12\x66\n\x12\x61\x63tion_description\x18\x06 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.ActionDescriptionR\x11\x61\x63tionDescription\x12t\n\x10rollback_context\x18\x07 \x01(\x0b\x32I.com.digitalasset.canton.protocol.v30.ViewParticipantData.RollbackContextR\x0frollbackContext\x1a+\n\x07\x46reeKey\x12 \n\x0bmaintainers\x18\x01 \x03(\tR\x0bmaintainers\x1a\xda\x01\n\x0bResolvedKey\x12\x41\n\x03key\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.GlobalKeyR\x03key\x12!\n\x0b\x63ontract_id\x18\x02 \x01(\tH\x00R\ncontractId\x12W\n\x04\x66ree\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.ViewParticipantData.FreeKeyH\x00R\x04\x66reeB\x0c\n\nresolution\x1aW\n\x0fRollbackContext\x12%\n\x0erollback_scope\x18\x01 \x03(\x05R\rrollbackScope\x12\x1d\n\nnext_child\x18\x02 \x01(\x05R\tnextChild\"\x81\x01\n\x1a\x45xternalPartyAuthorization\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"\xf1\x02\n\x15\x45xternalAuthorization\x12j\n\x0f\x61uthentications\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.protocol.v30.ExternalPartyAuthorizationR\x0f\x61uthentications\x12\x86\x01\n\x16hashing_scheme_version\x18\x02 \x01(\x0e\x32P.com.digitalasset.canton.protocol.v30.ExternalAuthorization.HashingSchemeVersionR\x14hashingSchemeVersion\"c\n\x14HashingSchemeVersion\x12&\n\"HASHING_SCHEME_VERSION_UNSPECIFIED\x10\x00\x12\x1d\n\x19HASHING_SCHEME_VERSION_V2\x10\x02\"\x04\x08\x01\x10\x01\x42UZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.participant_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_VIEWPARTICIPANTMESSAGE']._loaded_options = None
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_options = b'\030\001'
  _globals['_DEDUPLICATIONPERIOD']._serialized_start=400
  _globals['_DEDUPLICATIONPERIOD']._serialized_end=514
  _globals['_PARTICIPANTMETADATA']._serialized_start=517
  _globals['_PARTICIPANTMETADATA']._serialized_end=709
  _globals['_ROOTHASHMESSAGE']._serialized_start=712
  _globals['_ROOTHASHMESSAGE']._serialized_end=977
  _globals['_VIEWNODE']._serialized_start=980
  _globals['_VIEWNODE']._serialized_end=1267
  _globals['_VIEWCOMMONDATA']._serialized_start=1270
  _globals['_VIEWCOMMONDATA']._serialized_end=1450
  _globals['_INFORMEE']._serialized_start=1452
  _globals['_INFORMEE']._serialized_end=1508
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_start=1510
  _globals['_VIEWPARTICIPANTMESSAGE']._serialized_end=1538
  _globals['_INFORMEEMESSAGE']._serialized_start=1541
  _globals['_INFORMEEMESSAGE']._serialized_end=1781
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_start=1784
  _globals['_LIGHTTRANSACTIONVIEWTREE']._serialized_end=1997
  _globals['_VIEWHASHANDKEY']._serialized_start=1999
  _globals['_VIEWHASHANDKEY']._serialized_end=2113
  _globals['_FULLINFORMEETREE']._serialized_start=2115
  _globals['_FULLINFORMEETREE']._serialized_end=2211
  _globals['_CREATEDCONTRACT']._serialized_start=2213
  _globals['_CREATEDCONTRACT']._serialized_end=2333
  _globals['_INPUTCONTRACT']._serialized_start=2335
  _globals['_INPUTCONTRACT']._serialized_end=2406
  _globals['_COMMONMETADATA']._serialized_start=2409
  _globals['_COMMONMETADATA']._serialized_end=2610
  _globals['_SUBMITTERMETADATA']._serialized_start=2613
  _globals['_SUBMITTERMETADATA']._serialized_end=3130
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_start=3133
  _globals['_ENCRYPTEDVIEWMESSAGE']._serialized_end=3673
  _globals['_ACTIONDESCRIPTION']._serialized_start=3676
  _globals['_ACTIONDESCRIPTION']._serialized_end=4924
  _globals['_ACTIONDESCRIPTION_CREATEACTIONDESCRIPTION']._serialized_start=4145
  _globals['_ACTIONDESCRIPTION_CREATEACTIONDESCRIPTION']._serialized_end=4232
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_start=4235
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_end=4602
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_start=4605
  _globals['_ACTIONDESCRIPTION_FETCHACTIONDESCRIPTION']._serialized_end=4810
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_start=4812
  _globals['_ACTIONDESCRIPTION_LOOKUPBYKEYACTIONDESCRIPTION']._serialized_end=4909
  _globals['_VIEWPARTICIPANTDATA']._serialized_start=4927
  _globals['_VIEWPARTICIPANTDATA']._serialized_end=5948
  _globals['_VIEWPARTICIPANTDATA_FREEKEY']._serialized_start=5595
  _globals['_VIEWPARTICIPANTDATA_FREEKEY']._serialized_end=5638
  _globals['_VIEWPARTICIPANTDATA_RESOLVEDKEY']._serialized_start=5641
  _globals['_VIEWPARTICIPANTDATA_RESOLVEDKEY']._serialized_end=5859
  _globals['_VIEWPARTICIPANTDATA_ROLLBACKCONTEXT']._serialized_start=5861
  _globals['_VIEWPARTICIPANTDATA_ROLLBACKCONTEXT']._serialized_end=5948
  _globals['_EXTERNALPARTYAUTHORIZATION']._serialized_start=5951
  _globals['_EXTERNALPARTYAUTHORIZATION']._serialized_end=6080
  _globals['_EXTERNALAUTHORIZATION']._serialized_start=6083
  _globals['_EXTERNALAUTHORIZATION']._serialized_end=6452
  _globals['_EXTERNALAUTHORIZATION_HASHINGSCHEMEVERSION']._serialized_start=6353
  _globals['_EXTERNALAUTHORIZATION_HASHINGSCHEMEVERSION']._serialized_end=6452
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.package_metadata_filter import PackageMetadataFilter
    from ..models.topology_state_filter import TopologyStateFilter


T = TypeVar("T", bound="ListVettedPackagesRequest")


@_attrs_define
class ListVettedPackagesRequest:
    """
    Attributes:
        page_token (str): Pagination token to determine the specific page to fetch. Using the token
            guarantees that ``VettedPackages`` on a subsequent page are all greater
            (``VettedPackages`` are sorted by synchronizer ID then participant ID) than
            the last ``VettedPackages`` on a previous page.

            The server does not store intermediate results between calls chained by a
            series of page tokens. As a consequence, if new vetted packages are being
            added and a page is requested twice using the same token, more packages can
            be returned on the second call.

            Leave unspecified (i.e. as empty string) to fetch the first page.

            Optional
        page_size (int): Maximum number of ``VettedPackages`` results to return in a single page.

            If the page_size is unspecified (i.e. left as 0), the server will decide
            the number of results to be returned.

            If the page_size exceeds the maximum supported by the server, an
            error will be returned.

            To obtain the server's maximum consult the PackageService descriptor
            available in the VersionService.

            Optional
        package_metadata_filter (PackageMetadataFilter | Unset): Filter the VettedPackages by package metadata.

            A PackageMetadataFilter without package_ids and without package_name_prefixes
            matches any vetted package.

            Non-empty fields specify candidate values of which at least one must match.
            If both fields are set, then a candidate is returned if it matches one of the fields.
        topology_state_filter (TopologyStateFilter | Unset): Filter the vetted packages by the participant and
            synchronizer that they are
            hosted on.

            Empty fields are ignored, such that a ``TopologyStateFilter`` without
            participant_ids and without synchronizer_ids matches a vetted package hosted
            on any participant and synchronizer.

            Non-empty fields specify candidate values of which at least one must match.
            If both fields are set then at least one candidate value must match from each
            field.
    """

    page_token: str
    page_size: int
    package_metadata_filter: PackageMetadataFilter | Unset = UNSET
    topology_state_filter: TopologyStateFilter | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        page_token = self.page_token

        page_size = self.page_size

        package_metadata_filter: dict[str, Any] | Unset = UNSET
        if not isinstance(self.package_metadata_filter, Unset):
            package_metadata_filter = self.package_metadata_filter.to_dict()

        topology_state_filter: dict[str, Any] | Unset = UNSET
        if not isinstance(self.topology_state_filter, Unset):
            topology_state_filter = self.topology_state_filter.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "pageToken": page_token,
                "pageSize": page_size,
            }
        )
        if package_metadata_filter is not UNSET:
            field_dict["packageMetadataFilter"] = package_metadata_filter
        if topology_state_filter is not UNSET:
            field_dict["topologyStateFilter"] = topology_state_filter

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.package_metadata_filter import PackageMetadataFilter
        from ..models.topology_state_filter import TopologyStateFilter

        d = dict(src_dict)
        page_token = d.pop("pageToken")

        page_size = d.pop("pageSize")

        _package_metadata_filter = d.pop("packageMetadataFilter", UNSET)
        package_metadata_filter: PackageMetadataFilter | Unset
        if isinstance(_package_metadata_filter, Unset):
            package_metadata_filter = UNSET
        else:
            package_metadata_filter = PackageMetadataFilter.from_dict(
                _package_metadata_filter
            )

        _topology_state_filter = d.pop("topologyStateFilter", UNSET)
        topology_state_filter: TopologyStateFilter | Unset
        if isinstance(_topology_state_filter, Unset):
            topology_state_filter = UNSET
        else:
            topology_state_filter = TopologyStateFilter.from_dict(
                _topology_state_filter
            )

        list_vetted_packages_request = cls(
            page_token=page_token,
            page_size=page_size,
            package_metadata_filter=package_metadata_filter,
            topology_state_filter=topology_state_filter,
        )

        list_vetted_packages_request.additional_properties = d
        return list_vetted_packages_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="GetLatestPrunedOffsetsResponse")


@_attrs_define
class GetLatestPrunedOffsetsResponse:
    """
    Attributes:
        participant_pruned_up_to_inclusive (int): It will always be a non-negative integer.
            If positive, the absolute offset up to which the ledger has been pruned,
            disregarding the state of all divulged contracts pruning.
            If zero, the ledger has not been pruned yet.
        all_divulged_contracts_pruned_up_to_inclusive (int): It will always be a non-negative integer.
            If positive, the absolute offset up to which all divulged events have been pruned on the ledger.
            It can be at or before the ``participant_pruned_up_to_inclusive`` offset.
            For more details about all divulged events pruning,
            see ``PruneRequest.prune_all_divulged_contracts`` in ``participant_pruning_service.proto``.
            If zero, the divulged events have not been pruned yet.
    """

    participant_pruned_up_to_inclusive: int
    all_divulged_contracts_pruned_up_to_inclusive: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        participant_pruned_up_to_inclusive = self.participant_pruned_up_to_inclusive

        all_divulged_contracts_pruned_up_to_inclusive = (
            self.all_divulged_contracts_pruned_up_to_inclusive
        )

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "participantPrunedUpToInclusive": participant_pruned_up_to_inclusive,
                "allDivulgedContractsPrunedUpToInclusive": all_divulged_contracts_pruned_up_to_inclusive,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        participant_pruned_up_to_inclusive = d.pop("participantPrunedUpToInclusive")

        all_divulged_contracts_pruned_up_to_inclusive = d.pop(
            "allDivulgedContractsPrunedUpToInclusive"
        )

        get_latest_pruned_offsets_response = cls(
            participant_pruned_up_to_inclusive=participant_pruned_up_to_inclusive,
            all_divulged_contracts_pruned_up_to_inclusive=all_divulged_contracts_pruned_up_to_inclusive,
        )

        get_latest_pruned_offsets_response.additional_properties = d
        return get_latest_pruned_offsets_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from .. import package_reference_pb2 as _package_reference_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UpdateVettedPackagesForceFlag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UPDATE_VETTED_PACKAGES_FORCE_FLAG_UNSPECIFIED: _ClassVar[UpdateVettedPackagesForceFlag]
    UPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_VET_INCOMPATIBLE_UPGRADES: _ClassVar[UpdateVettedPackagesForceFlag]
    UPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_UNVETTED_DEPENDENCIES: _ClassVar[UpdateVettedPackagesForceFlag]
UPDATE_VETTED_PACKAGES_FORCE_FLAG_UNSPECIFIED: UpdateVettedPackagesForceFlag
UPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_VET_INCOMPATIBLE_UPGRADES: UpdateVettedPackagesForceFlag
UPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_UNVETTED_DEPENDENCIES: UpdateVettedPackagesForceFlag

class ListKnownPackagesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListKnownPackagesResponse(_message.Message):
    __slots__ = ("package_details",)
    PACKAGE_DETAILS_FIELD_NUMBER: _ClassVar[int]
    package_details: _containers.RepeatedCompositeFieldContainer[PackageDetails]
    def __init__(self, package_details: _Optional[_Iterable[_Union[PackageDetails, _Mapping]]] = ...) -> None: ...

class PackageDetails(_message.Message):
    __slots__ = ("package_id", "package_size", "known_since", "name", "version")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    KNOWN_SINCE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    package_size: int
    known_since: _timestamp_pb2.Timestamp
    name: str
    version: str
    def __init__(self, package_id: _Optional[str] = ..., package_size: _Optional[int] = ..., known_since: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., name: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class UploadDarFileRequest(_message.Message):
    __slots__ = ("dar_file", "submission_id", "vetting_change", "synchronizer_id")
    class VettingChange(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VETTING_CHANGE_UNSPECIFIED: _ClassVar[UploadDarFileRequest.VettingChange]
        VETTING_CHANGE_VET_ALL_PACKAGES: _ClassVar[UploadDarFileRequest.VettingChange]
        VETTING_CHANGE_DONT_VET_ANY_PACKAGES: _ClassVar[UploadDarFileRequest.VettingChange]
    VETTING_CHANGE_UNSPECIFIED: UploadDarFileRequest.VettingChange
    VETTING_CHANGE_VET_ALL_PACKAGES: UploadDarFileRequest.VettingChange
    VETTING_CHANGE_DONT_VET_ANY_PACKAGES: UploadDarFileRequest.VettingChange
    DAR_FILE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    VETTING_CHANGE_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    dar_file: bytes
    submission_id: str
    vetting_change: UploadDarFileRequest.VettingChange
    synchronizer_id: str
    def __init__(self, dar_file: _Optional[bytes] = ..., submission_id: _Optional[str] = ..., vetting_change: _Optional[_Union[UploadDarFileRequest.VettingChange, str]] = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class UploadDarFileResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ValidateDarFileRequest(_message.Message):
    __slots__ = ("dar_file", "submission_id", "synchronizer_id")
    DAR_FILE_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    dar_file: bytes
    submission_id: str
    synchronizer_id: str
    def __init__(self, dar_file: _Optional[bytes] = ..., submission_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ...) -> None: ...

class ValidateDarFileResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class VettedPackagesChange(_message.Message):
    __slots__ = ("vet", "unvet")
    class Unvet(_message.Message):
        __slots__ = ("packages",)
        PACKAGES_FIELD_NUMBER: _ClassVar[int]
        packages: _containers.RepeatedCompositeFieldContainer[VettedPackagesRef]
        def __init__(self, packages: _Optional[_Iterable[_Union[VettedPackagesRef, _Mapping]]] = ...) -> None: ...
    class Vet(_message.Message):
        __slots__ = ("packages", "new_valid_from_inclusive", "new_valid_until_exclusive")
        PACKAGES_FIELD_NUMBER: _ClassVar[int]
        NEW_VALID_FROM_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        NEW_VALID_UNTIL_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        packages: _containers.RepeatedCompositeFieldContainer[VettedPackagesRef]
        new_valid_from_inclusive: _timestamp_pb2.Timestamp
        new_valid_until_exclusive: _timestamp_pb2.Timestamp
        def __init__(self, packages: _Optional[_Iterable[_Union[VettedPackagesRef, _Mapping]]] = ..., new_valid_from_inclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., new_valid_until_exclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    VET_FIELD_NUMBER: _ClassVar[int]
    UNVET_FIELD_NUMBER: _ClassVar[int]
    vet: VettedPackagesChange.Vet
    unvet: VettedPackagesChange.Unvet
    def __init__(self, vet: _Optional[_Union[VettedPackagesChange.Vet, _Mapping]] = ..., unvet: _Optional[_Union[VettedPackagesChange.Unvet, _Mapping]] = ...) -> None: ...

class VettedPackagesRef(_message.Message):
    __slots__ = ("package_id", "package_name", "package_version")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    package_name: str
    package_version: str
    def __init__(self, package_id: _Optional[str] = ..., package_name: _Optional[str] = ..., package_version: _Optional[str] = ...) -> None: ...

class UpdateVettedPackagesRequest(_message.Message):
    __slots__ = ("changes", "dry_run", "synchronizer_id", "expected_topology_serial", "update_vetted_packages_force_flags")
    CHANGES_FIELD_NUMBER: _ClassVar[int]
    DRY_RUN_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
    UPDATE_VETTED_PACKAGES_FORCE_FLAGS_FIELD_NUMBER: _ClassVar[int]
    changes: _containers.RepeatedCompositeFieldContainer[VettedPackagesChange]
    dry_run: bool
    synchronizer_id: str
    expected_topology_serial: _package_reference_pb2.PriorTopologySerial
    update_vetted_packages_force_flags: _containers.RepeatedScalarFieldContainer[UpdateVettedPackagesForceFlag]
    def __init__(self, changes: _Optional[_Iterable[_Union[VettedPackagesChange, _Mapping]]] = ..., dry_run: bool = ..., synchronizer_id: _Optional[str] = ..., expected_topology_serial: _Optional[_Union[_package_reference_pb2.PriorTopologySerial, _Mapping]] = ..., update_vetted_packages_force_flags: _Optional[_Iterable[_Union[UpdateVettedPackagesForceFlag, str]]] = ...) -> None: ...

class UpdateVettedPackagesResponse(_message.Message):
    __slots__ = ("past_vetted_packages", "new_vetted_packages")
    PAST_VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    NEW_VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    past_vetted_packages: _package_reference_pb2.VettedPackages
    new_vetted_packages: _package_reference_pb2.VettedPackages
    def __init__(self, past_vetted_packages: _Optional[_Union[_package_reference_pb2.VettedPackages, _Mapping]] = ..., new_vetted_packages: _Optional[_Union[_package_reference_pb2.VettedPackages, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .... import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nScom/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto\x12\x31\x63om.daml.ledger.api.v2.interactive.transaction.v1\x1a\"com/daml/ledger/api/v2/value.proto\"\xe3\x02\n\x05\x46\x65tch\x12\x1d\n\nlf_version\x18\x01 \x01(\tR\tlfVersion\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12 \n\x0bsignatories\x18\x05 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x06 \x03(\tR\x0cstakeholders\x12%\n\x0e\x61\x63ting_parties\x18\x07 \x03(\tR\ractingParties\x12\x45\n\x0cinterface_id\x18\x08 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\"\xf2\x04\n\x08\x45xercise\x12\x1d\n\nlf_version\x18\x01 \x01(\tR\tlfVersion\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12 \n\x0bsignatories\x18\x05 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x06 \x03(\tR\x0cstakeholders\x12%\n\x0e\x61\x63ting_parties\x18\x07 \x03(\tR\ractingParties\x12\x45\n\x0cinterface_id\x18\x08 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x1b\n\tchoice_id\x18\t \x01(\tR\x08\x63hoiceId\x12@\n\x0c\x63hosen_value\x18\n \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63hosenValue\x12\x1c\n\tconsuming\x18\x0b \x01(\x08R\tconsuming\x12\x1a\n\x08\x63hildren\x18\x0c \x03(\tR\x08\x63hildren\x12\x46\n\x0f\x65xercise_result\x18\r \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x65xerciseResult\x12)\n\x10\x63hoice_observers\x18\x0e \x03(\tR\x0f\x63hoiceObservers\"\xb1\x02\n\x06\x43reate\x12\x1d\n\nlf_version\x18\x01 \x01(\tR\tlfVersion\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x39\n\x08\x61rgument\x18\x05 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x08\x61rgument\x12 \n\x0bsignatories\x18\x06 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x07 \x03(\tR\x0cstakeholders\"&\n\x08Rollback\x12\x1a\n\x08\x63hildren\x18\x01 \x03(\tR\x08\x63hildren\"\xf0\x02\n\x04Node\x12S\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x39.com.daml.ledger.api.v2.interactive.transaction.v1.CreateH\x00R\x06\x63reate\x12P\n\x05\x66\x65tch\x18\x02 \x01(\x0b\x32\x38.com.daml.ledger.api.v2.interactive.transaction.v1.FetchH\x00R\x05\x66\x65tch\x12Y\n\x08\x65xercise\x18\x03 \x01(\x0b\x32;.com.daml.ledger.api.v2.interactive.transaction.v1.ExerciseH\x00R\x08\x65xercise\x12Y\n\x08rollback\x18\x04 \x01(\x0b\x32;.com.daml.ledger.api.v2.interactive.transaction.v1.RollbackH\x00R\x08rollbackB\x0b\n\tnode_typeB\xee\x01\n1com.daml.ledger.api.v2.interactive.transaction.v1B#InteractiveSubmissionDataOuterClassZ`github.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive/transaction/v1\xaa\x02\x31\x43om.Daml.Ledger.Api.V2.Interactive.Transaction.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive.transaction.v1.interactive_submission_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.daml.ledger.api.v2.interactive.transaction.v1B#InteractiveSubmissionDataOuterClassZ`github.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive/transaction/v1\252\0021Com.Daml.Ledger.Api.V2.Interactive.Transaction.V1'
  _globals['_FETCH']._serialized_start=175
  _globals['_FETCH']._serialized_end=530
  _globals['_EXERCISE']._serialized_start=533
  _globals['_EXERCISE']._serialized_end=1159
  _globals['_CREATE']._serialized_start=1162
  _globals['_CREATE']._serialized_end=1467
  _globals['_ROLLBACK']._serialized_start=1469
  _globals['_ROLLBACK']._serialized_end=1507
  _globals['_NODE']._serialized_start=1510
  _globals['_NODE']._serialized_end=1878
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from . import acs_import_pb2 as _acs_import_pb2
from . import synchronizer_connectivity_pb2 as _synchronizer_connectivity_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PurgeContractsRequest(_message.Message):
    __slots__ = ("synchronizer_alias", "contract_ids", "ignore_already_purged")
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_IDS_FIELD_NUMBER: _ClassVar[int]
    IGNORE_ALREADY_PURGED_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    contract_ids: _containers.RepeatedScalarFieldContainer[str]
    ignore_already_purged: bool
    def __init__(self, synchronizer_alias: _Optional[str] = ..., contract_ids: _Optional[_Iterable[str]] = ..., ignore_already_purged: bool = ...) -> None: ...

class PurgeContractsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ChangeAssignationRequest(_message.Message):
    __slots__ = ("source_synchronizer_alias", "target_synchronizer_alias", "skip_inactive", "contracts")
    class Contract(_message.Message):
        __slots__ = ("id", "reassignment_counter_override")
        ID_FIELD_NUMBER: _ClassVar[int]
        REASSIGNMENT_COUNTER_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        id: str
        reassignment_counter_override: int
        def __init__(self, id: _Optional[str] = ..., reassignment_counter_override: _Optional[int] = ...) -> None: ...
    SOURCE_SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    TARGET_SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    SKIP_INACTIVE_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    source_synchronizer_alias: str
    target_synchronizer_alias: str
    skip_inactive: bool
    contracts: _containers.RepeatedCompositeFieldContainer[ChangeAssignationRequest.Contract]
    def __init__(self, source_synchronizer_alias: _Optional[str] = ..., target_synchronizer_alias: _Optional[str] = ..., skip_inactive: bool = ..., contracts: _Optional[_Iterable[_Union[ChangeAssignationRequest.Contract, _Mapping]]] = ...) -> None: ...

class ChangeAssignationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MigrateSynchronizerRequest(_message.Message):
    __slots__ = ("source_synchronizer_alias", "target_synchronizer_connection_config", "force")
    SOURCE_SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    TARGET_SYNCHRONIZER_CONNECTION_CONFIG_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    source_synchronizer_alias: str
    target_synchronizer_connection_config: _synchronizer_connectivity_pb2.SynchronizerConnectionConfig
    force: bool
    def __init__(self, source_synchronizer_alias: _Optional[str] = ..., target_synchronizer_connection_config: _Optional[_Union[_synchronizer_connectivity_pb2.SynchronizerConnectionConfig, _Mapping]] = ..., force: bool = ...) -> None: ...

class MigrateSynchronizerResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ExportAcsOldRequest(_message.Message):
    __slots__ = ("parties", "filter_synchronizer_id", "timestamp", "force", "parties_offboarding")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    FILTER_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    PARTIES_OFFBOARDING_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    filter_synchronizer_id: str
    timestamp: _timestamp_pb2.Timestamp
    force: bool
    parties_offboarding: bool
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., filter_synchronizer_id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., force: bool = ..., parties_offboarding: bool = ...) -> None: ...

class ExportAcsOldResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ImportAcsOldRequest(_message.Message):
    __slots__ = ("acs_snapshot", "workflow_id_prefix", "allow_contract_id_suffix_recomputation")
    ACS_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_PREFIX_FIELD_NUMBER: _ClassVar[int]
    ALLOW_CONTRACT_ID_SUFFIX_RECOMPUTATION_FIELD_NUMBER: _ClassVar[int]
    acs_snapshot: bytes
    workflow_id_prefix: str
    allow_contract_id_suffix_recomputation: bool
    def __init__(self, acs_snapshot: _Optional[bytes] = ..., workflow_id_prefix: _Optional[str] = ..., allow_contract_id_suffix_recomputation: bool = ...) -> None: ...

class ImportAcsOldResponse(_message.Message):
    __slots__ = ("contract_id_mapping",)
    class ContractIdMappingEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CONTRACT_ID_MAPPING_FIELD_NUMBER: _ClassVar[int]
    contract_id_mapping: _containers.ScalarMap[str, str]
    def __init__(self, contract_id_mapping: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ExportAcsTargetSynchronizer(_message.Message):
    __slots__ = ("target_synchronizer_id",)
    TARGET_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    target_synchronizer_id: str
    def __init__(self, target_synchronizer_id: _Optional[str] = ...) -> None: ...

class ExportAcsRequest(_message.Message):
    __slots__ = ("party_ids", "synchronizer_id", "ledger_offset", "contract_synchronizer_renames", "excluded_stakeholder_ids")
    class ContractSynchronizerRenamesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ExportAcsTargetSynchronizer
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ExportAcsTargetSynchronizer, _Mapping]] = ...) -> None: ...
    PARTY_IDS_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    LEDGER_OFFSET_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_SYNCHRONIZER_RENAMES_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_STAKEHOLDER_IDS_FIELD_NUMBER: _ClassVar[int]
    party_ids: _containers.RepeatedScalarFieldContainer[str]
    synchronizer_id: str
    ledger_offset: int
    contract_synchronizer_renames: _containers.MessageMap[str, ExportAcsTargetSynchronizer]
    excluded_stakeholder_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, party_ids: _Optional[_Iterable[str]] = ..., synchronizer_id: _Optional[str] = ..., ledger_offset: _Optional[int] = ..., contract_synchronizer_renames: _Optional[_Mapping[str, ExportAcsTargetSynchronizer]] = ..., excluded_stakeholder_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ExportAcsResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ImportAcsRequest(_message.Message):
    __slots__ = ("acs_snapshot", "workflow_id_prefix", "contract_import_mode", "excluded_stakeholder_ids", "representative_package_id_override")
    ACS_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_PREFIX_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_IMPORT_MODE_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_STAKEHOLDER_IDS_FIELD_NUMBER: _ClassVar[int]
    REPRESENTATIVE_PACKAGE_ID_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    acs_snapshot: bytes
    workflow_id_prefix: str
    contract_import_mode: _acs_import_pb2.ContractImportMode
    excluded_stakeholder_ids: _containers.RepeatedScalarFieldContainer[str]
    representative_package_id_override: _acs_import_pb2.RepresentativePackageIdOverride
    def __init__(self, acs_snapshot: _Optional[bytes] = ..., workflow_id_prefix: _Optional[str] = ..., contract_import_mode: _Optional[_Union[_acs_import_pb2.ContractImportMode, str]] = ..., excluded_stakeholder_ids: _Optional[_Iterable[str]] = ..., representative_package_id_override: _Optional[_Union[_acs_import_pb2.RepresentativePackageIdOverride, _Mapping]] = ...) -> None: ...

class ImportAcsResponse(_message.Message):
    __slots__ = ("contract_id_mappings",)
    class ContractIdMappingsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CONTRACT_ID_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    contract_id_mappings: _containers.ScalarMap[str, str]
    def __init__(self, contract_id_mappings: _Optional[_Mapping[str, str]] = ...) -> None: ...

class PurgeDeactivatedSynchronizerRequest(_message.Message):
    __slots__ = ("synchronizer_alias",)
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    def __init__(self, synchronizer_alias: _Optional[str] = ...) -> None: ...

class PurgeDeactivatedSynchronizerResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IgnoreEventsRequest(_message.Message):
    __slots__ = ("physical_synchronizer_id", "from_inclusive", "to_inclusive", "force")
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    FROM_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    physical_synchronizer_id: str
    from_inclusive: int
    to_inclusive: int
    force: bool
    def __init__(self, physical_synchronizer_id: _Optional[str] = ..., from_inclusive: _Optional[int] = ..., to_inclusive: _Optional[int] = ..., force: bool = ...) -> None: ...

class IgnoreEventsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UnignoreEventsRequest(_message.Message):
    __slots__ = ("physical_synchronizer_id", "from_inclusive", "to_inclusive", "force")
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    FROM_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    physical_synchronizer_id: str
    from_inclusive: int
    to_inclusive: int
    force: bool
    def __init__(self, physical_synchronizer_id: _Optional[str] = ..., from_inclusive: _Optional[int] = ..., to_inclusive: _Optional[int] = ..., force: bool = ...) -> None: ...

class UnignoreEventsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RollbackUnassignmentRequest(_message.Message):
    __slots__ = ("reassignment_id", "source_synchronizer_id", "target_synchronizer_id")
    REASSIGNMENT_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    reassignment_id: str
    source_synchronizer_id: str
    target_synchronizer_id: str
    def __init__(self, reassignment_id: _Optional[str] = ..., source_synchronizer_id: _Optional[str] = ..., target_synchronizer_id: _Optional[str] = ...) -> None: ...

class RollbackUnassignmentResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RepairCommitmentsUsingAcsRequest(_message.Message):
    __slots__ = ("synchronizer_ids", "counter_participant_ids", "party_ids", "timeout_seconds")
    SYNCHRONIZER_IDS_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_IDS_FIELD_NUMBER: _ClassVar[int]
    PARTY_IDS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_SECONDS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_ids: _containers.RepeatedScalarFieldContainer[str]
    counter_participant_ids: _containers.RepeatedScalarFieldContainer[str]
    party_ids: _containers.RepeatedScalarFieldContainer[str]
    timeout_seconds: _duration_pb2.Duration
    def __init__(self, synchronizer_ids: _Optional[_Iterable[str]] = ..., counter_participant_ids: _Optional[_Iterable[str]] = ..., party_ids: _Optional[_Iterable[str]] = ..., timeout_seconds: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class RepairCommitmentsUsingAcsResponse(_message.Message):
    __slots__ = ("statuses",)
    STATUSES_FIELD_NUMBER: _ClassVar[int]
    statuses: _containers.RepeatedCompositeFieldContainer[RepairCommitmentsStatus]
    def __init__(self, statuses: _Optional[_Iterable[_Union[RepairCommitmentsStatus, _Mapping]]] = ...) -> None: ...

class RepairCommitmentsStatus(_message.Message):
    __slots__ = ("synchronizer_id", "error_message", "completed_repair_timestamp")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_REPAIR_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    error_message: str
    completed_repair_timestamp: _timestamp_pb2.Timestamp
    def __init__(self, synchronizer_id: _Optional[str] = ..., error_message: _Optional[str] = ..., completed_repair_timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/sequencer/v30/sequencer_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/sequencer/v30/sequencer_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...health.v30 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_health_dot_v30_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJcom/digitalasset/canton/admin/sequencer/v30/sequencer_status_service.proto\x12+com.digitalasset.canton.admin.sequencer.v30\x1a=com/digitalasset/canton/admin/health/v30/status_service.proto\"\x18\n\x16SequencerStatusRequest\"\x8b\x08\n\x17SequencerStatusResponse\x12|\n\x06status\x18\x01 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponse.SequencerStatusResponseStatusH\x00R\x06status\x12\x63\n\x0fnot_initialized\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.health.v30.NotInitializedH\x00R\x0enotInitialized\x1a(\n\x14\x43onnectedParticipant\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x1a%\n\x11\x43onnectedMediator\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x1a\xb3\x05\n\x1dSequencerStatusResponseStatus\x12U\n\rcommon_status\x18\x01 \x01(\x0b\x32\x30.com.digitalasset.canton.admin.health.v30.StatusR\x0c\x63ommonStatus\x12\x90\x01\n\x16\x63onnected_participants\x18\x02 \x03(\x0b\x32Y.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponse.ConnectedParticipantR\x15\x63onnectedParticipants\x12\x87\x01\n\x13\x63onnected_mediators\x18\x03 \x03(\x0b\x32V.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponse.ConnectedMediatorR\x12\x63onnectedMediators\x12`\n\tsequencer\x18\x04 \x01(\x0b\x32\x42.com.digitalasset.canton.admin.sequencer.v30.SequencerHealthStatusR\tsequencer\x12\x38\n\x18physical_synchronizer_id\x18\x05 \x01(\tR\x16physicalSynchronizerId\x12W\n\x05\x61\x64min\x18\x06 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.sequencer.v30.SequencerAdminStatusR\x05\x61\x64min\x12)\n\x10protocol_version\x18\x07 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind\"Z\n\x15SequencerHealthStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x1d\n\x07\x64\x65tails\x18\x02 \x01(\tH\x00R\x07\x64\x65tails\x88\x01\x01\x42\n\n\x08_details\"J\n\x14SequencerAdminStatus\x12\x32\n\x15\x61\x63\x63\x65pts_admin_changes\x18\x01 \x01(\x08R\x13\x61\x63\x63\x65ptsAdminChanges2\xb7\x01\n\x16SequencerStatusService\x12\x9c\x01\n\x0fSequencerStatus\x12\x43.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusRequest\x1a\x44.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.sequencer.v30.sequencer_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30'
  _globals['_SEQUENCERSTATUSREQUEST']._serialized_start=186
  _globals['_SEQUENCERSTATUSREQUEST']._serialized_end=210
  _globals['_SEQUENCERSTATUSRESPONSE']._serialized_start=213
  _globals['_SEQUENCERSTATUSRESPONSE']._serialized_end=1248
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDPARTICIPANT']._serialized_start=467
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDPARTICIPANT']._serialized_end=507
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDMEDIATOR']._serialized_start=509
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDMEDIATOR']._serialized_end=546
  _globals['_SEQUENCERSTATUSRESPONSE_SEQUENCERSTATUSRESPONSESTATUS']._serialized_start=549
  _globals['_SEQUENCERSTATUSRESPONSE_SEQUENCERSTATUSRESPONSESTATUS']._serialized_end=1240
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_start=1250
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_end=1340
  _globals['_SEQUENCERADMINSTATUS']._serialized_start=1342
  _globals['_SEQUENCERADMINSTATUS']._serialized_end=1416
  _globals['_SEQUENCERSTATUSSERVICE']._serialized_start=1419
  _globals['_SEQUENCERSTATUSSERVICE']._serialized_end=1602
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from enum import Enum


class TransactionFormatTransactionShape(str, Enum):
    TRANSACTION_SHAPE_ACS_DELTA = "TRANSACTION_SHAPE_ACS_DELTA"
    TRANSACTION_SHAPE_LEDGER_EFFECTS = "TRANSACTION_SHAPE_LEDGER_EFFECTS"
    TRANSACTION_SHAPE_UNSPECIFIED = "TRANSACTION_SHAPE_UNSPECIFIED"

    def __str__(self) -> str:
        return str(self.value)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .mediator_status_service_pb2 import MediatorStatusRequest, MediatorStatusResponse

__all__ = [
    "MediatorStatusServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class MediatorStatusServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _MediatorStatusServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _MediatorStatusServiceAsyncStub: ...  # type: ignore
    def MediatorStatus(self, __1: MediatorStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> MediatorStatusResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, MediatorStatusResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _MediatorStatusServiceBlockingStub(MediatorStatusServiceStub):
    def MediatorStatus(self, __1: MediatorStatusRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> MediatorStatusResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _MediatorStatusServiceAsyncStub(MediatorStatusServiceStub):
    def MediatorStatus(self, __1: MediatorStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, MediatorStatusResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/sequencer_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/domain/admin/v0/sequencer_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....health.admin.v0 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v0_dot_status__service__pb2
from ....health.admin.v1 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v1_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/domain/admin/v0/sequencer_status_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a<com/digitalasset/canton/health/admin/v0/status_service.proto\x1a<com/digitalasset/canton/health/admin/v1/status_service.proto\"\x18\n\x16SequencerStatusRequest\"\xba\x06\n\x17SequencerStatusResponse\x12x\n\x06status\x18\x01 \x01(\x0b\x32^.com.digitalasset.canton.domain.admin.v0.SequencerStatusResponse.SequencerStatusResponseStatusH\x00R\x06status\x12\x66\n\x0bunavailable\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.health.admin.v0.NodeStatus.NotInitializedH\x00R\x0bunavailable\x12L\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32\x30.com.digitalasset.canton.health.admin.v1.FailureH\x00R\x07\x66\x61ilure\x1a\xe6\x03\n\x1dSequencerStatusResponseStatus\x12T\n\rcommon_status\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.health.admin.v1.StatusR\x0c\x63ommonStatus\x12<\n\x1a\x63onnected_participants_uid\x18\x02 \x03(\tR\x18\x63onnectedParticipantsUid\x12\x36\n\x17\x63onnected_mediators_uid\x18\x07 \x03(\tR\x15\x63onnectedMediatorsUid\x12\\\n\tsequencer\x18\x03 \x01(\x0b\x32>.com.digitalasset.canton.health.admin.v0.SequencerHealthStatusR\tsequencer\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\x12S\n\x05\x61\x64min\x18\x05 \x01(\x0b\x32=.com.digitalasset.canton.health.admin.v0.SequencerAdminStatusR\x05\x61\x64min\x12)\n\x10protocol_version\x18\x06 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind2\xaf\x01\n\x16SequencerStatusService\x12\x94\x01\n\x0fSequencerStatus\x12?.com.digitalasset.canton.domain.admin.v0.SequencerStatusRequest\x1a@.com.digitalasset.canton.domain.admin.v0.SequencerStatusResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.sequencer_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_SEQUENCERSTATUSREQUEST']._serialized_start=239
  _globals['_SEQUENCERSTATUSREQUEST']._serialized_end=263
  _globals['_SEQUENCERSTATUSRESPONSE']._serialized_start=266
  _globals['_SEQUENCERSTATUSRESPONSE']._serialized_end=1092
  _globals['_SEQUENCERSTATUSRESPONSE_SEQUENCERSTATUSRESPONSESTATUS']._serialized_start=598
  _globals['_SEQUENCERSTATUSRESPONSE_SEQUENCERSTATUSRESPONSESTATUS']._serialized_end=1084
  _globals['_SEQUENCERSTATUSSERVICE']._serialized_start=1095
  _globals['_SEQUENCERSTATUSSERVICE']._serialized_end=1270
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class OrderingRequest(_message.Message):
    __slots__ = ("sequencer_uid", "content")
    SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    sequencer_uid: str
    content: bytes
    def __init__(self, sequencer_uid: _Optional[str] = ..., content: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/initialization_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/topology/admin/v30/initialization_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\"\xc3\x01\n\rInitIdRequest\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12t\n\x15namespace_delegations\x18\x03 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x14namespaceDelegations\"\x10\n\x0eInitIdResponse\"^\n\rGetIdResponse\x12 \n\x0binitialized\x18\x01 \x01(\x08R\x0binitialized\x12+\n\x11unique_identifier\x18\x02 \x01(\tR\x10uniqueIdentifier\"\"\n GetOnboardingTransactionsRequest\"\x89\x01\n!GetOnboardingTransactionsResponse\x12\x64\n\x0ctransactions\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x0ctransactions\"\x0e\n\x0cGetIdRequest\"\x14\n\x12\x43urrentTimeRequest\"8\n\x13\x43urrentTimeResponse\x12!\n\x0c\x63urrent_time\x18\x01 \x01(\x03R\x0b\x63urrentTime2\xaf\x03\n\x1dIdentityInitializationService\x12\x7f\n\x06InitId\x12\x39.com.digitalasset.canton.topology.admin.v30.InitIdRequest\x1a:.com.digitalasset.canton.topology.admin.v30.InitIdResponse\x12|\n\x05GetId\x12\x38.com.digitalasset.canton.topology.admin.v30.GetIdRequest\x1a\x39.com.digitalasset.canton.topology.admin.v30.GetIdResponse\x12\x8e\x01\n\x0b\x43urrentTime\x12>.com.digitalasset.canton.topology.admin.v30.CurrentTimeRequest\x1a?.com.digitalasset.canton.topology.admin.v30.CurrentTimeResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_INITIDREQUEST']._serialized_start=230
  _globals['_INITIDREQUEST']._serialized_end=425
  _globals['_INITIDRESPONSE']._serialized_start=427
  _globals['_INITIDRESPONSE']._serialized_end=443
  _globals['_GETIDRESPONSE']._serialized_start=445
  _globals['_GETIDRESPONSE']._serialized_end=539
  _globals['_GETONBOARDINGTRANSACTIONSREQUEST']._serialized_start=541
  _globals['_GETONBOARDINGTRANSACTIONSREQUEST']._serialized_end=575
  _globals['_GETONBOARDINGTRANSACTIONSRESPONSE']._serialized_start=578
  _globals['_GETONBOARDINGTRANSACTIONSRESPONSE']._serialized_end=715
  _globals['_GETIDREQUEST']._serialized_start=717
  _globals['_GETIDREQUEST']._serialized_end=731
  _globals['_CURRENTTIMEREQUEST']._serialized_start=733
  _globals['_CURRENTTIMEREQUEST']._serialized_end=753
  _globals['_CURRENTTIMERESPONSE']._serialized_start=755
  _globals['_CURRENTTIMERESPONSE']._serialized_end=811
  _globals['_IDENTITYINITIALIZATIONSERVICE']._serialized_start=814
  _globals['_IDENTITYINITIALIZATIONSERVICE']._serialized_end=1245
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.signing_public_key import SigningPublicKey


T = TypeVar("T", bound="GenerateExternalPartyTopologyRequest")


@_attrs_define
class GenerateExternalPartyTopologyRequest:
    """
    Attributes:
        synchronizer (str): TODO(#27670) support synchronizer aliases
            Required: synchronizer-id for which we are building this request.
        party_hint (str): Required: the actual party id will be constructed from this hint and a fingerprint of the
            public key
        local_participant_observation_only (bool): Optional: if true, then the local participant will only be observing,
            not confirming. Default false.
        confirmation_threshold (int): Optional: Confirmation threshold >= 1 for the party. Defaults to all available
            confirmers (or if set to 0).
        public_key (SigningPublicKey | Unset):
        other_confirming_participant_uids (list[str] | Unset): Optional: other participant ids which should be
            confirming for this party
        observing_participant_uids (list[str] | Unset): Optional: other observing participant ids for this party
    """

    synchronizer: str
    party_hint: str
    local_participant_observation_only: bool
    confirmation_threshold: int
    public_key: SigningPublicKey | Unset = UNSET
    other_confirming_participant_uids: list[str] | Unset = UNSET
    observing_participant_uids: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        synchronizer = self.synchronizer

        party_hint = self.party_hint

        local_participant_observation_only = self.local_participant_observation_only

        confirmation_threshold = self.confirmation_threshold

        public_key: dict[str, Any] | Unset = UNSET
        if not isinstance(self.public_key, Unset):
            public_key = self.public_key.to_dict()

        other_confirming_participant_uids: list[str] | Unset = UNSET
        if not isinstance(self.other_confirming_participant_uids, Unset):
            other_confirming_participant_uids = self.other_confirming_participant_uids

        observing_participant_uids: list[str] | Unset = UNSET
        if not isinstance(self.observing_participant_uids, Unset):
            observing_participant_uids = self.observing_participant_uids

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "synchronizer": synchronizer,
                "partyHint": party_hint,
                "localParticipantObservationOnly": local_participant_observation_only,
                "confirmationThreshold": confirmation_threshold,
            }
        )
        if public_key is not UNSET:
            field_dict["publicKey"] = public_key
        if other_confirming_participant_uids is not UNSET:
            field_dict["otherConfirmingParticipantUids"] = (
                other_confirming_participant_uids
            )
        if observing_participant_uids is not UNSET:
            field_dict["observingParticipantUids"] = observing_participant_uids

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.signing_public_key import SigningPublicKey

        d = dict(src_dict)
        synchronizer = d.pop("synchronizer")

        party_hint = d.pop("partyHint")

        local_participant_observation_only = d.pop("localParticipantObservationOnly")

        confirmation_threshold = d.pop("confirmationThreshold")

        _public_key = d.pop("publicKey", UNSET)
        public_key: SigningPublicKey | Unset
        if isinstance(_public_key, Unset):
            public_key = UNSET
        else:
            public_key = SigningPublicKey.from_dict(_public_key)

        other_confirming_participant_uids = cast(
            list[str], d.pop("otherConfirmingParticipantUids", UNSET)
        )

        observing_participant_uids = cast(
            list[str], d.pop("observingParticipantUids", UNSET)
        )

        generate_external_party_topology_request = cls(
            synchronizer=synchronizer,
            party_hint=party_hint,
            local_participant_observation_only=local_participant_observation_only,
            confirmation_threshold=confirmation_threshold,
            public_key=public_key,
            other_confirming_participant_uids=other_confirming_participant_uids,
            observing_participant_uids=observing_participant_uids,
        )

        generate_external_party_topology_request.additional_properties = d
        return generate_external_party_topology_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ..v0 import status_service_pb2 as _status_service_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Failure(_message.Message):
    __slots__ = ("error_message",)
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    error_message: str
    def __init__(self, error_message: _Optional[str] = ...) -> None: ...

class Status(_message.Message):
    __slots__ = ("uid", "uptime", "ports", "active", "topology_queues", "components", "version")
    class PortsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    UID_FIELD_NUMBER: _ClassVar[int]
    UPTIME_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_QUEUES_FIELD_NUMBER: _ClassVar[int]
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    uid: str
    uptime: _duration_pb2.Duration
    ports: _containers.ScalarMap[str, int]
    active: bool
    topology_queues: _status_service_pb2.TopologyQueueStatus
    components: _containers.RepeatedCompositeFieldContainer[_status_service_pb2.NodeStatus.ComponentStatus]
    version: str
    def __init__(self, uid: _Optional[str] = ..., uptime: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., ports: _Optional[_Mapping[str, int]] = ..., active: bool = ..., topology_queues: _Optional[_Union[_status_service_pb2.TopologyQueueStatus, _Mapping]] = ..., components: _Optional[_Iterable[_Union[_status_service_pb2.NodeStatus.ComponentStatus, _Mapping]]] = ..., version: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .crypto_pb2 import HmacAlgorithm, Salt

__all__ = [
    "HmacAlgorithm",
    "Salt",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from collections.abc import Sequence as Seq
from os import PathLike
import sys
from typing import AsyncContextManager, BinaryIO, Callable, Literal, Optional, Sequence, overload

from ..ledger.aio import Connection
from ..prim import Parties, Party

if sys.version_info >= (3, 11):
    from typing import TypeAlias
else:
    from typing_extensions import TypeAlias

__all__ = ["connect_with_new_party"]

NameGenFn: TypeAlias = Callable[[int], Optional[str]]

@overload
def connect_with_new_party(
    *,
    party_count: Literal[1] = 1,
    url: Optional[str] = None,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    admin: Optional[bool] = False,
    ledger_id: Optional[str] = None,
    dar: Optional[str | bytes | PathLike | BinaryIO] = None,
    identifier_hint: Optional[str | NameGenFn] = None,
    display_name: Optional[str | NameGenFn] = None,
) -> AsyncContextManager[ConnectionWithParty]: ...
@overload
def connect_with_new_party(
    *,
    party_count: Literal[2],
    url: Optional[str] = None,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    admin: Optional[bool] = False,
    ledger_id: Optional[str] = None,
    dar: Optional[str | bytes | PathLike | BinaryIO] = None,
    identifier_hint: Optional[str | NameGenFn] = None,
    display_name: Optional[str | NameGenFn] = None,
) -> AsyncContextManager[tuple[ConnectionWithParty, ConnectionWithParty]]: ...
@overload
def connect_with_new_party(
    *,
    party_count: Literal[3],
    url: Optional[str] = None,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    admin: Optional[bool] = False,
    ledger_id: Optional[str] = None,
    dar: Optional[str | bytes | PathLike | BinaryIO] = None,
    identifier_hint: Optional[str | NameGenFn] = None,
    display_name: Optional[str | NameGenFn] = None,
) -> AsyncContextManager[tuple[ConnectionWithParty, ConnectionWithParty, ConnectionWithParty]]: ...
@overload
def connect_with_new_party(
    *,
    party_count: Literal[4],
    url: Optional[str] = None,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    admin: Optional[bool] = False,
    ledger_id: Optional[str] = None,
    dar: Optional[str | bytes | PathLike | BinaryIO] = None,
    identifier_hint: Optional[str | NameGenFn] = None,
    display_name: Optional[str | NameGenFn] = None,
) -> AsyncContextManager[
    tuple[ConnectionWithParty, ConnectionWithParty, ConnectionWithParty, ConnectionWithParty]
]: ...
@overload
def connect_with_new_party(
    *,
    party_count: int,
    url: Optional[str] = None,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    admin: Optional[bool] = False,
    ledger_id: Optional[str] = None,
    dar: Optional[str | bytes | PathLike | BinaryIO] = None,
    identifier_hint: Optional[str | NameGenFn] = None,
    display_name: Optional[str | NameGenFn] = None,
) -> AsyncContextManager[Sequence[ConnectionWithParty]]: ...

class ConnectionWithParty(Seq["ConnectionWithParty"]):
    def __init__(self, connection: Connection, party: Party): ...
    @property
    def connection(self) -> Connection: ...
    @property
    def party(self) -> Party: ...
    def __getitem__(self, item): ...
    def __len__(self) -> Literal[1]: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="VettedPackage")


@_attrs_define
class VettedPackage:
    """A package that is vetting on a given participant and synchronizer,
    modelled after ``VettedPackage`` in `topology.proto <https://github.com/digital-
    asset/canton/blob/main/community/base/src/main/protobuf/com/digitalasset/canton/protocol/v30/topology.proto#L206>`_,
    enriched with the package name and version.

        Attributes:
            package_id (str): Package ID of this package. Always present.
            package_name (str): Name of this package.
                Only available if the package has been uploaded to the current participant.
                If unavailable, is empty string.
            package_version (str): Version of this package.
                Only available if the package has been uploaded to the current participant.
                If unavailable, is empty string.
            valid_from_inclusive (str | Unset): The time from which this package is vetted. Empty if vetting time has no
                lower bound.
            valid_until_exclusive (str | Unset): The time until which this package is vetted. Empty if vetting time has no
                upper bound.
    """

    package_id: str
    package_name: str
    package_version: str
    valid_from_inclusive: str | Unset = UNSET
    valid_until_exclusive: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        package_id = self.package_id

        package_name = self.package_name

        package_version = self.package_version

        valid_from_inclusive = self.valid_from_inclusive

        valid_until_exclusive = self.valid_until_exclusive

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "packageId": package_id,
                "packageName": package_name,
                "packageVersion": package_version,
            }
        )
        if valid_from_inclusive is not UNSET:
            field_dict["validFromInclusive"] = valid_from_inclusive
        if valid_until_exclusive is not UNSET:
            field_dict["validUntilExclusive"] = valid_until_exclusive

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        package_id = d.pop("packageId", "")

        package_name = d.pop("packageName", "")

        package_version = d.pop("packageVersion", "")

        valid_from_inclusive = d.pop("validFromInclusive", UNSET)

        valid_until_exclusive = d.pop("validUntilExclusive", UNSET)

        vetted_package = cls(
            package_id=package_id,
            package_name=package_name,
            package_version=package_version,
            valid_from_inclusive=valid_from_inclusive,
            valid_until_exclusive=valid_until_exclusive,
        )

        vetted_package.additional_properties = d
        return vetted_package

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/participant_reassignment.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/participant_reassignment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_merkle__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/protocol/v30/participant_reassignment.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/merkle.proto\x1a\x1fgoogle/protobuf/timestamp.proto\" \n\x0eReassignmentId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xf3\x03\n\x16UnassignmentCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x45\n\x1fsource_physical_synchronizer_id\x18\x02 \x01(\tR\x1csourcePhysicalSynchronizerId\x12V\n\x0cstakeholders\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.StakeholdersR\x0cstakeholders\x12@\n\x1creassigning_participant_uids\x18\x04 \x03(\tR\x1areassigningParticipantUids\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x32\n\x15source_mediator_group\x18\x06 \x01(\x05R\x13sourceMediatorGroup\x12r\n\x12submitter_metadata\x18\x07 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ReassignmentSubmitterMetadataR\x11submitterMetadata\"\x97\x01\n\x14ReassignmentViewTree\x12\x1f\n\x0b\x63ommon_data\x18\x01 \x01(\x0cR\ncommonData\x12^\n\x10participant_data\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x0fparticipantData\"\xe4\x01\n\x19\x41ssignmentMediatorMessage\x12N\n\x04tree\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.ReassignmentViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xe6\x01\n\x1bUnassignmentMediatorMessage\x12N\n\x04tree\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.ReassignmentViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xfd\x04\n\x14\x41ssignmentCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x45\n\x1fsource_physical_synchronizer_id\x18\x08 \x01(\tR\x1csourcePhysicalSynchronizerId\x12\x45\n\x1ftarget_physical_synchronizer_id\x18\x02 \x01(\tR\x1ctargetPhysicalSynchronizerId\x12\x43\n\x0funassignment_ts\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0eunassignmentTs\x12V\n\x0cstakeholders\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.StakeholdersR\x0cstakeholders\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x32\n\x15target_mediator_group\x18\x05 \x01(\x05R\x13targetMediatorGroup\x12r\n\x12submitter_metadata\x18\x06 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ReassignmentSubmitterMetadataR\x11submitterMetadata\x12@\n\x1creassigning_participant_uids\x18\x07 \x03(\tR\x1areassigningParticipantUids\"\xf9\x01\n\x1dReassignmentSubmitterMetadata\x12\x1c\n\tsubmitter\x18\x01 \x01(\tR\tsubmitter\x12<\n\x1asubmitting_participant_uid\x18\x02 \x01(\tR\x18submittingParticipantUid\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12#\n\rsubmission_id\x18\x04 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x1f\n\x0bworkflow_id\x18\x06 \x01(\tR\nworkflowId\"\x96\x02\n\x10UnassignmentView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x45\n\x1ftarget_physical_synchronizer_id\x18\x02 \x01(\tR\x1ctargetPhysicalSynchronizerId\x12)\n\x10target_timestamp\x18\x03 \x01(\x03R\x0ftargetTimestamp\x12R\n\tcontracts\x18\x04 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ActiveContractR\tcontracts\"\xb6\x04\n\x10UnassignmentData\x12r\n\x12submitter_metadata\x18\x01 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ReassignmentSubmitterMetadataR\x11submitterMetadata\x12R\n\tcontracts\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ActiveContractR\tcontracts\x12@\n\x1creassigning_participant_uids\x18\x03 \x03(\tR\x1areassigningParticipantUids\x12\x45\n\x1fsource_physical_synchronizer_id\x18\x04 \x01(\tR\x1csourcePhysicalSynchronizerId\x12\x45\n\x1ftarget_physical_synchronizer_id\x18\x05 \x01(\tR\x1ctargetPhysicalSynchronizerId\x12\x45\n\x10target_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0ftargetTimestamp\x12\x43\n\x0funassignment_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0eunassignmentTs\"\x81\x02\n\x0e\x41ssignmentView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12R\n\tcontracts\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ActiveContractR\tcontracts\x12]\n\x0freassignment_id\x18\x03 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ReassignmentIdR\x0ereassignmentId\"_\n\x0e\x41\x63tiveContract\x12\x1a\n\x08\x63ontract\x18\x01 \x01(\x0cR\x08\x63ontract\x12\x31\n\x14reassignment_counter\x18\x02 \x01(\x03R\x13reassignmentCounterBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.participant_reassignment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_REASSIGNMENTID']._serialized_start=300
  _globals['_REASSIGNMENTID']._serialized_end=332
  _globals['_UNASSIGNMENTCOMMONDATA']._serialized_start=335
  _globals['_UNASSIGNMENTCOMMONDATA']._serialized_end=834
  _globals['_REASSIGNMENTVIEWTREE']._serialized_start=837
  _globals['_REASSIGNMENTVIEWTREE']._serialized_end=988
  _globals['_ASSIGNMENTMEDIATORMESSAGE']._serialized_start=991
  _globals['_ASSIGNMENTMEDIATORMESSAGE']._serialized_end=1219
  _globals['_UNASSIGNMENTMEDIATORMESSAGE']._serialized_start=1222
  _globals['_UNASSIGNMENTMEDIATORMESSAGE']._serialized_end=1452
  _globals['_ASSIGNMENTCOMMONDATA']._serialized_start=1455
  _globals['_ASSIGNMENTCOMMONDATA']._serialized_end=2092
  _globals['_REASSIGNMENTSUBMITTERMETADATA']._serialized_start=2095
  _globals['_REASSIGNMENTSUBMITTERMETADATA']._serialized_end=2344
  _globals['_UNASSIGNMENTVIEW']._serialized_start=2347
  _globals['_UNASSIGNMENTVIEW']._serialized_end=2625
  _globals['_UNASSIGNMENTDATA']._serialized_start=2628
  _globals['_UNASSIGNMENTDATA']._serialized_end=3194
  _globals['_ASSIGNMENTVIEW']._serialized_start=3197
  _globals['_ASSIGNMENTVIEW']._serialized_end=3454
  _globals['_ACTIVECONTRACT']._serialized_start=3456
  _globals['_ACTIVECONTRACT']._serialized_end=3551
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ...sequencer.v30 import sequencer_connection_pb2 as _sequencer_connection_pb2
from ...time.v30 import time_tracker_config_pb2 as _time_tracker_config_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SynchronizerConnectionConfig(_message.Message):
    __slots__ = ("synchronizer_alias", "sequencer_connections", "manual_connect", "physical_synchronizer_id", "priority", "initial_retry_delay", "max_retry_delay", "time_tracker", "initialize_from_trusted_synchronizer")
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    MANUAL_CONNECT_FIELD_NUMBER: _ClassVar[int]
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    INITIAL_RETRY_DELAY_FIELD_NUMBER: _ClassVar[int]
    MAX_RETRY_DELAY_FIELD_NUMBER: _ClassVar[int]
    TIME_TRACKER_FIELD_NUMBER: _ClassVar[int]
    INITIALIZE_FROM_TRUSTED_SYNCHRONIZER_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    sequencer_connections: _sequencer_connection_pb2.SequencerConnections
    manual_connect: bool
    physical_synchronizer_id: str
    priority: int
    initial_retry_delay: _duration_pb2.Duration
    max_retry_delay: _duration_pb2.Duration
    time_tracker: _time_tracker_config_pb2.SynchronizerTimeTrackerConfig
    initialize_from_trusted_synchronizer: bool
    def __init__(self, synchronizer_alias: _Optional[str] = ..., sequencer_connections: _Optional[_Union[_sequencer_connection_pb2.SequencerConnections, _Mapping]] = ..., manual_connect: bool = ..., physical_synchronizer_id: _Optional[str] = ..., priority: _Optional[int] = ..., initial_retry_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_retry_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., time_tracker: _Optional[_Union[_time_tracker_config_pb2.SynchronizerTimeTrackerConfig, _Mapping]] = ..., initialize_from_trusted_synchronizer: bool = ...) -> None: ...

class ReconnectSynchronizersRequest(_message.Message):
    __slots__ = ("ignore_failures",)
    IGNORE_FAILURES_FIELD_NUMBER: _ClassVar[int]
    ignore_failures: bool
    def __init__(self, ignore_failures: bool = ...) -> None: ...

class ReconnectSynchronizersResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RegisterSynchronizerRequest(_message.Message):
    __slots__ = ("config", "synchronizer_connection", "sequencer_connection_validation")
    class SynchronizerConnection(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SYNCHRONIZER_CONNECTION_UNSPECIFIED: _ClassVar[RegisterSynchronizerRequest.SynchronizerConnection]
        SYNCHRONIZER_CONNECTION_NONE: _ClassVar[RegisterSynchronizerRequest.SynchronizerConnection]
        SYNCHRONIZER_CONNECTION_HANDSHAKE: _ClassVar[RegisterSynchronizerRequest.SynchronizerConnection]
    SYNCHRONIZER_CONNECTION_UNSPECIFIED: RegisterSynchronizerRequest.SynchronizerConnection
    SYNCHRONIZER_CONNECTION_NONE: RegisterSynchronizerRequest.SynchronizerConnection
    SYNCHRONIZER_CONNECTION_HANDSHAKE: RegisterSynchronizerRequest.SynchronizerConnection
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_CONNECTION_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    config: SynchronizerConnectionConfig
    synchronizer_connection: RegisterSynchronizerRequest.SynchronizerConnection
    sequencer_connection_validation: _sequencer_connection_pb2.SequencerConnectionValidation
    def __init__(self, config: _Optional[_Union[SynchronizerConnectionConfig, _Mapping]] = ..., synchronizer_connection: _Optional[_Union[RegisterSynchronizerRequest.SynchronizerConnection, str]] = ..., sequencer_connection_validation: _Optional[_Union[_sequencer_connection_pb2.SequencerConnectionValidation, str]] = ...) -> None: ...

class RegisterSynchronizerResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ModifySynchronizerRequest(_message.Message):
    __slots__ = ("physical_synchronizer_id", "new_config", "sequencer_connection_validation")
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    NEW_CONFIG_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    physical_synchronizer_id: str
    new_config: SynchronizerConnectionConfig
    sequencer_connection_validation: _sequencer_connection_pb2.SequencerConnectionValidation
    def __init__(self, physical_synchronizer_id: _Optional[str] = ..., new_config: _Optional[_Union[SynchronizerConnectionConfig, _Mapping]] = ..., sequencer_connection_validation: _Optional[_Union[_sequencer_connection_pb2.SequencerConnectionValidation, str]] = ...) -> None: ...

class ModifySynchronizerResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListRegisteredSynchronizersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListRegisteredSynchronizersResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("config", "connected", "physical_synchronizer_id")
        CONFIG_FIELD_NUMBER: _ClassVar[int]
        CONNECTED_FIELD_NUMBER: _ClassVar[int]
        PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
        config: SynchronizerConnectionConfig
        connected: bool
        physical_synchronizer_id: str
        def __init__(self, config: _Optional[_Union[SynchronizerConnectionConfig, _Mapping]] = ..., connected: bool = ..., physical_synchronizer_id: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListRegisteredSynchronizersResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListRegisteredSynchronizersResponse.Result, _Mapping]]] = ...) -> None: ...

class ReconnectSynchronizerRequest(_message.Message):
    __slots__ = ("synchronizer_alias", "retry")
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    RETRY_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    retry: bool
    def __init__(self, synchronizer_alias: _Optional[str] = ..., retry: bool = ...) -> None: ...

class ReconnectSynchronizerResponse(_message.Message):
    __slots__ = ("connected_successfully",)
    CONNECTED_SUCCESSFULLY_FIELD_NUMBER: _ClassVar[int]
    connected_successfully: bool
    def __init__(self, connected_successfully: bool = ...) -> None: ...

class ConnectSynchronizerRequest(_message.Message):
    __slots__ = ("config", "sequencer_connection_validation")
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    config: SynchronizerConnectionConfig
    sequencer_connection_validation: _sequencer_connection_pb2.SequencerConnectionValidation
    def __init__(self, config: _Optional[_Union[SynchronizerConnectionConfig, _Mapping]] = ..., sequencer_connection_validation: _Optional[_Union[_sequencer_connection_pb2.SequencerConnectionValidation, str]] = ...) -> None: ...

class ConnectSynchronizerResponse(_message.Message):
    __slots__ = ("connected_successfully",)
    CONNECTED_SUCCESSFULLY_FIELD_NUMBER: _ClassVar[int]
    connected_successfully: bool
    def __init__(self, connected_successfully: bool = ...) -> None: ...

class DisconnectSynchronizerRequest(_message.Message):
    __slots__ = ("synchronizer_alias",)
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    def __init__(self, synchronizer_alias: _Optional[str] = ...) -> None: ...

class DisconnectSynchronizerResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DisconnectAllSynchronizersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DisconnectAllSynchronizersResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListConnectedSynchronizersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListConnectedSynchronizersResponse(_message.Message):
    __slots__ = ("connected_synchronizers",)
    class Result(_message.Message):
        __slots__ = ("synchronizer_alias", "synchronizer_id", "physical_synchronizer_id", "healthy")
        SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
        SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
        PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
        HEALTHY_FIELD_NUMBER: _ClassVar[int]
        synchronizer_alias: str
        synchronizer_id: str
        physical_synchronizer_id: str
        healthy: bool
        def __init__(self, synchronizer_alias: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., physical_synchronizer_id: _Optional[str] = ..., healthy: bool = ...) -> None: ...
    CONNECTED_SYNCHRONIZERS_FIELD_NUMBER: _ClassVar[int]
    connected_synchronizers: _containers.RepeatedCompositeFieldContainer[ListConnectedSynchronizersResponse.Result]
    def __init__(self, connected_synchronizers: _Optional[_Iterable[_Union[ListConnectedSynchronizersResponse.Result, _Mapping]]] = ...) -> None: ...

class GetSynchronizerIdRequest(_message.Message):
    __slots__ = ("synchronizer_alias",)
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    def __init__(self, synchronizer_alias: _Optional[str] = ...) -> None: ...

class GetSynchronizerIdResponse(_message.Message):
    __slots__ = ("synchronizer_id", "physical_synchronizer_id")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    physical_synchronizer_id: str
    def __init__(self, synchronizer_id: _Optional[str] = ..., physical_synchronizer_id: _Optional[str] = ...) -> None: ...

class LogoutRequest(_message.Message):
    __slots__ = ("synchronizer_alias",)
    SYNCHRONIZER_ALIAS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_alias: str
    def __init__(self, synchronizer_alias: _Optional[str] = ...) -> None: ...

class LogoutResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .object_meta_pb2 import ObjectMeta
from .user_management_service_pb2 import CreateUserRequest, CreateUserResponse, DeleteUserRequest, DeleteUserResponse, GetUserRequest, GetUserResponse, GrantUserRightsRequest, GrantUserRightsResponse, ListUserRightsRequest, ListUserRightsResponse, ListUsersRequest, ListUsersResponse, RevokeUserRightsRequest, RevokeUserRightsResponse, Right, UpdateUserIdentityProviderIdRequest, UpdateUserIdentityProviderIdResponse, UpdateUserRequest, UpdateUserResponse, User
from .user_management_service_pb2_grpc import UserManagementServiceStub
from .package_management_service_pb2 import ListKnownPackagesRequest, ListKnownPackagesResponse, PackageDetails, UpdateVettedPackagesForceFlag, UpdateVettedPackagesRequest, UpdateVettedPackagesResponse, UploadDarFileRequest, UploadDarFileResponse, ValidateDarFileRequest, ValidateDarFileResponse, VettedPackagesChange, VettedPackagesRef
from .package_management_service_pb2_grpc import PackageManagementServiceStub
from .participant_pruning_service_pb2 import PruneRequest, PruneResponse
from .participant_pruning_service_pb2_grpc import ParticipantPruningServiceStub
from .party_management_service_pb2 import AllocateExternalPartyRequest, AllocateExternalPartyResponse, AllocatePartyRequest, AllocatePartyResponse, GenerateExternalPartyTopologyRequest, GenerateExternalPartyTopologyResponse, GetParticipantIdRequest, GetParticipantIdResponse, GetPartiesRequest, GetPartiesResponse, ListKnownPartiesRequest, ListKnownPartiesResponse, PartyDetails, UpdatePartyDetailsRequest, UpdatePartyDetailsResponse, UpdatePartyIdentityProviderIdRequest, UpdatePartyIdentityProviderIdResponse
from .party_management_service_pb2_grpc import PartyManagementServiceStub
from .identity_provider_config_service_pb2 import CreateIdentityProviderConfigRequest, CreateIdentityProviderConfigResponse, DeleteIdentityProviderConfigRequest, DeleteIdentityProviderConfigResponse, GetIdentityProviderConfigRequest, GetIdentityProviderConfigResponse, IdentityProviderConfig, ListIdentityProviderConfigsRequest, ListIdentityProviderConfigsResponse, UpdateIdentityProviderConfigRequest, UpdateIdentityProviderConfigResponse
from .identity_provider_config_service_pb2_grpc import IdentityProviderConfigServiceStub
from .command_inspection_service_pb2 import CommandState, CommandStatus, CommandUpdates, Contract, GetCommandStatusRequest, GetCommandStatusResponse, RequestStatistics
from .command_inspection_service_pb2_grpc import CommandInspectionServiceStub

__all__ = [
    "AllocateExternalPartyRequest",
    "AllocateExternalPartyResponse",
    "AllocatePartyRequest",
    "AllocatePartyResponse",
    "CommandInspectionServiceStub",
    "CommandState",
    "CommandStatus",
    "CommandUpdates",
    "Contract",
    "CreateIdentityProviderConfigRequest",
    "CreateIdentityProviderConfigResponse",
    "CreateUserRequest",
    "CreateUserResponse",
    "DeleteIdentityProviderConfigRequest",
    "DeleteIdentityProviderConfigResponse",
    "DeleteUserRequest",
    "DeleteUserResponse",
    "GenerateExternalPartyTopologyRequest",
    "GenerateExternalPartyTopologyResponse",
    "GetCommandStatusRequest",
    "GetCommandStatusResponse",
    "GetIdentityProviderConfigRequest",
    "GetIdentityProviderConfigResponse",
    "GetParticipantIdRequest",
    "GetParticipantIdResponse",
    "GetPartiesRequest",
    "GetPartiesResponse",
    "GetUserRequest",
    "GetUserResponse",
    "GrantUserRightsRequest",
    "GrantUserRightsResponse",
    "IdentityProviderConfig",
    "IdentityProviderConfigServiceStub",
    "ListIdentityProviderConfigsRequest",
    "ListIdentityProviderConfigsResponse",
    "ListKnownPackagesRequest",
    "ListKnownPackagesResponse",
    "ListKnownPartiesRequest",
    "ListKnownPartiesResponse",
    "ListUserRightsRequest",
    "ListUserRightsResponse",
    "ListUsersRequest",
    "ListUsersResponse",
    "ObjectMeta",
    "PackageDetails",
    "PackageManagementServiceStub",
    "ParticipantPruningServiceStub",
    "PartyDetails",
    "PartyManagementServiceStub",
    "PruneRequest",
    "PruneResponse",
    "RequestStatistics",
    "RevokeUserRightsRequest",
    "RevokeUserRightsResponse",
    "Right",
    "UpdateIdentityProviderConfigRequest",
    "UpdateIdentityProviderConfigResponse",
    "UpdatePartyDetailsRequest",
    "UpdatePartyDetailsResponse",
    "UpdatePartyIdentityProviderIdRequest",
    "UpdatePartyIdentityProviderIdResponse",
    "UpdateUserIdentityProviderIdRequest",
    "UpdateUserIdentityProviderIdResponse",
    "UpdateUserRequest",
    "UpdateUserResponse",
    "UpdateVettedPackagesForceFlag",
    "UpdateVettedPackagesRequest",
    "UpdateVettedPackagesResponse",
    "UploadDarFileRequest",
    "UploadDarFileResponse",
    "User",
    "UserManagementServiceStub",
    "ValidateDarFileRequest",
    "ValidateDarFileResponse",
    "VettedPackagesChange",
    "VettedPackagesRef",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from datetime import datetime
from typing import (
    AbstractSet,
    Any,
    Iterator,
    Optional,
    Protocol,
    Sequence,
    TypeVar,
    runtime_checkable,
)

from ...damlast.daml_lf_1 import PackageRef, TypeConName
from ...prim import ContractData, ContractId, Parties, TimeDeltaLike
from ...query import Queries, Query
from ..api_types import (
    ArchiveEvent,
    Boundary,
    Commands,
    CreateEvent,
    ExerciseResponse,
    MeteringReport,
    PartyInfo,
    Right,
    User,
    Version,
)
from ..auth import TokenOrTokenProvider

__all__ = ["PackageService", "Connection", "QueryStream"]

Self = TypeVar("Self")

class PackageService(Protocol):
    def get_package(
        self,
        package_id: PackageRef,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> bytes: ...
    def list_package_ids(
        self,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> AbstractSet[PackageRef]: ...

@runtime_checkable
class Connection(PackageService, Protocol):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, exc_type, exc_val, exc_tb) -> None: ...
    def open(self) -> None: ...
    def close(self) -> None: ...
    def submit(
        self,
        commands: Commands,
        /,
        *,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> None: ...
    def create(
        self,
        template_id: str | TypeConName,
        payload: ContractData,
        /,
        *,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> CreateEvent: ...
    def exercise(
        self,
        contract_id: ContractId,
        choice_name: str,
        argument: Optional[ContractData] = ...,
        /,
        *,
        choice_interface_id: None | str | TypeConName = ...,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> ExerciseResponse: ...
    def create_and_exercise(
        self,
        template_id: str | TypeConName,
        payload: ContractData,
        choice_name: str,
        argument: Optional[ContractData] = ...,
        /,
        *,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> ExerciseResponse: ...
    def exercise_by_key(
        self,
        template_id: str | TypeConName,
        choice_name: str,
        key: Any,
        argument: Optional[ContractData] = ...,
        /,
        *,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> ExerciseResponse: ...
    def archive(
        self,
        contract_id: ContractId,
        /,
        *,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> ArchiveEvent: ...
    def archive_by_key(
        self,
        template_id: str,
        key: Any,
        /,
        *,
        workflow_id: Optional[str] = ...,
        command_id: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        act_as: Optional[Parties] = ...,
        user_id: Optional[str] = ...,
        deduplication_duration: Optional[TimeDeltaLike] = ...,
        deduplication_offset: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> ArchiveEvent: ...
    def get_ledger_end(
        self,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> str: ...
    def query(
        self,
        template_id: str | TypeConName = "*",
        query: Query = ...,
        /,
        *,
        read_as: Optional[Parties] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> QueryStream: ...
    def query_many(
        self,
        *queries: Queries,
        read_as: Optional[Parties] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> QueryStream: ...
    def stream(
        self,
        template_id: str | TypeConName = "*",
        query: Query = ...,
        /,
        *,
        offset: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> QueryStream: ...
    def stream_many(
        self,
        *queries: Queries,
        offset: Optional[str] = ...,
        read_as: Optional[Parties] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> QueryStream: ...
    def get_user(
        self,
        user_id: Optional[str] = ...,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> User: ...
    def create_user(
        self,
        user: User,
        rights: Optional[Sequence[Right]] = ...,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> User: ...
    def list_users(
        self,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> Sequence[User]: ...
    def list_user_rights(
        self,
        user_id: Optional[str] = ...,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> Sequence[Right]: ...
    def allocate_party(
        self,
        *,
        identifier_hint: Optional[str] = ...,
        display_name: Optional[str] = ...,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> PartyInfo: ...
    def list_known_parties(
        self,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> Sequence[PartyInfo]: ...
    def get_version(
        self,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> Version: ...
    def upload_package(
        self,
        contents: bytes,
        /,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> None: ...
    def get_metering_report(
        self,
        from_: datetime,
        to: Optional[datetime] = ...,
        application_id: Optional[str] = ...,
        *,
        token: Optional[TokenOrTokenProvider] = ...,
        timeout: Optional[TimeDeltaLike] = ...,
    ) -> MeteringReport: ...

@runtime_checkable
class QueryStream(Protocol):
    def creates(self) -> Iterator[CreateEvent]: ...
    def events(self) -> Iterator[CreateEvent | ArchiveEvent]: ...
    def items(self) -> Iterator[CreateEvent | ArchiveEvent | Boundary]: ...
    def __iter__(self) -> Iterator[CreateEvent | ArchiveEvent | Boundary]: ...
    def run(self) -> None: ...
    def close(self) -> None: ...
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, exc_type, exc_val, exc_tb) -> None: ...
